/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.admin;

import java.util.Properties;

import org.ow2.petals.basisapi.exception.PetalsException;

/**
 * Client interface of the service 'PetalsAdmin'
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface PetalsAdminService {

    /**
     * <p>
     * Retrieve all the properties of the server local configuration (ie. the content of '<code>server.properties</code>
     * ' or equivalent, including:
     * <ul>
     * <li>the configured properties and unset properties.
     * </p>
     * <p>
     * Unset properties are returned as set to an empty {@link String}.
     * </p>
     * 
     * @return The properties of the server local configuration.
     * 
     * @throws PetalsException
     */
    public Properties retrieveServerProperties() throws PetalsException;
    
    /**
     * Ping if the server is ready to process messages in the domain
     * 
     * @return <code>true</code> if "ping" succeeds.
     * @throws PetalsException
     */
    public boolean ping() throws PetalsException;

    /**
     * Unload the container from the Petals global environment. All ServiceAssemblies, Components and Share Libraries
     * are stopped, shutdown, and uninstalled. All registered Endpoints are deactivated. Then the container is removed
     * from the domain.
     * 
     * @throws PetalsException
     */
    public void shutdownContainer() throws PetalsException;

    /**
     * Stop the container. The container is still visible in the Petals global environment, but marked as 'stopped'. The
     * registered Endpoints are still visible,too.
     * 
     * @throws PetalsException
     */
    public void stopContainer() throws PetalsException;
}
