/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.jbi.management.deployment;

import javax.jbi.management.DeploymentServiceMBean;

import org.ow2.petals.clientserverapi.jbi.management.recovery.SystemRecoveryService;

/**
 * Client/server interface of the deployment service. Few methods are added to {@link DeploymentServiceMBean} for
 * reinstallation tasks of the {@link SystemRecoveryService} service.
 * 
 * @author Olivier Fabre - EBM WebSourcing
 */
public interface DeploymentService extends javax.jbi.management.DeploymentServiceMBean {

    /**
     * Try to undeploy a service assembly. If the SA is in the STARTED state, it will be previously stopped and shut
     * down. If the SA is in the STOPPED state, it will be previously shut down.
     * 
     * @return true if the SA is undeployed, false otherwise.
     */
    public boolean forceUndeploy(final String name);

    /**
     * Get all the service unit names for the given service assembly
     * 
     * @param saName
     * @return
     */
    public String[] getServiceUnitForServiceAssembly(final String saName) throws Exception;

    /**
     * Try to shutdown all service assemblies. If a service assembly can't be shut down, the shutting down process isn't
     * aborted. It returns the list of all shutdown service assemblies.
     * 
     * @return an array of successfully shutdown service assembly names.
     */
    public String[] shutdownAllServiceAssemblies();

    /**
     * Try to start all service assemblies. If a service assembly can't be started, the starting process isn't aborted.
     * It returns the list of all started service assemblies.
     * 
     * @return an array of successfully started service assembly names.
     */
    public String[] startAllServiceAssemblies();

    /**
     * Try to stop all service assemblies. If a service assembly can't be stopped, the stopping process isn't aborted.
     * It returns the list of all stopped service assemblies.
     * 
     * @return an array of successfully stopped service assembly names.
     */
    public String[] stopAllServiceAssemblies();

    /**
     * Try to undeploy all service assemblies. The undeployment can be forced; in this case, the deployment process is
     * completed as this : if the SA is in the STARTED state, it will be stopped and shutdown. If the SA is in the
     * STOPPED state, it will be shutdown. If a service assembly can't be undeployed, the undeploying process isn't
     * aborted. It returns the list of all undeployed service assemblies.
     * 
     * @param force
     *            true if you want to force undeployment, ignoring assembly state. Default is false
     * @return an array of successfully undeployed service assembly names.
     */
    public String[] undeployAllServiceAssemblies(final boolean force);

}
